@@ -103,9 +103,7 @@ class UserProfile:
         )
 
     def to_dict(self):
-        rv = {
-            "id": str(self.user_id),
-        }
+        rv = {"id": str(self.user_id)}
         if self.name:
             rv["name"] = self.name
         if self.gender:
